/* --COPYRIGHT--,BSD
 * Copyright (c) 2017, Helmholtz Centre for Environmental Research - UFZ
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/
/*******************************************************************************
 * hal_DRV8711.h
 *
 * Hardware abstraction layer for the BOOST-DRV8711 on MSP-EXP430FR6989
 *
 *  Created on: 07.02.2017
 *      Author: G. Laube
 */

#ifndef HAL_DRV8711_H_
#define HAL_DRV8711_H_

#include "DRV8711_registers.h"

void init_DRV8711(void);
void DRV8711_turnMotor(long);
void DRV8711_stopMotor(void);
void DRV8711_incrementStep(void);
void DRV8711_decrementStep(void);
void DRV8711_resetFaults(void);
void DRV8711_writeAllRegisters(void);
void DRV8711_readAllRegisters(void);
unsigned short DRV8711_SPI_readWrite(unsigned char, unsigned char);
void DRV8711_reset(void);
void DRV8711_enter_sleep(void);
void DRV8711_exit_sleep(void);

volatile long step_counter;
volatile unsigned int step_period;
volatile unsigned char motorRunFlag;
short microstep_mode;
short microsteps;


// DRV8711 Registers
struct CTRL_Register     CTRL_REG;
struct TORQUE_Register   TORQUE_REG;
struct OFF_Register      OFF_REG;
struct BLANK_Register    BLANK_REG;
struct DECAY_Register    DECAY_REG;
struct STALL_Register    STALL_REG;
struct DRIVE_Register    DRIVE_REG;
struct STATUS_Register   STATUS_REG;

// DRV8711 Debug Registers
struct CTRL_Register     Test_CTRL_REG;
struct TORQUE_Register   Test_TORQUE_REG;
struct OFF_Register      Test_OFF_REG;
struct BLANK_Register    Test_BLANK_REG;
struct DECAY_Register    Test_DECAY_REG;
struct STALL_Register    Test_STALL_REG;
struct DRIVE_Register    Test_DRIVE_REG;
struct STATUS_Register   Test_STATUS_REG;

// Register Access
#define REGWRITE    0x00
#define REGREAD     0x80



#endif /* HAL_DRV8711_H_ */
